@@ -346,7 +346,7 @@ impl FastlyHttpReq for Session {
             .ok_or_else(|| Error::UnknownBackend(backend_name.to_owned()))?;
 
         // synchronously send the request
-        let resp = upstream::send_request(req, backend).await?;
+        let resp = upstream::send_request(req, backend, self.tls_config()).await?;
         Ok(self.insert_response(resp))
     }
 
@@ -368,7 +368,8 @@ impl FastlyHttpReq for Session {
             .ok_or_else(|| Error::UnknownBackend(backend_name.to_owned()))?;
 
         // asynchronously send the request
-        let pending_req = PendingRequest::spawn(upstream::send_request(req, backend));
+        let pending_req =
+            PendingRequest::spawn(upstream::send_request(req, backend, self.tls_config()));
 
         // return a handle to the pending request
         Ok(self.insert_pending_request(pending_req))
@@ -392,7 +393,8 @@ impl FastlyHttpReq for Session {
             .ok_or_else(|| Error::UnknownBackend(backend_name.to_owned()))?;
 
         // asynchronously send the request
-        let pending_req = PendingRequest::spawn(upstream::send_request(req, backend));
+        let pending_req =
+            PendingRequest::spawn(upstream::send_request(req, backend, self.tls_config()));
 
         // return a handle to the pending request
         Ok(self.insert_pending_request(pending_req))
